@@ -8,8 +8,9 @@ import time
 from tqdm import tqdm
 from pathlib import Path
 from collections import deque
+import sys
 
-
+from yolov6.utils.downloads import attempt_download_from_hub
 from yolov6.utils.events import LOGGER, load_yaml
 from yolov6.layers.common import DetectBackend
 from yolov6.data.datasets import LoadData
@@ -75,12 +76,12 @@ class YOLOV6:
         hide_labels = False,
         hide_conf = False,
         view_img = False,
-        font = './yolov6/utils/Arial.ttf'
+        hf_model = False
+        
     ):
 
         self.__dict__.update(locals())
-        self.weights = weights
-        self.device = torch.device('cpu' if device == 'cpu' else 'cuda:0' if torch.cuda.is_available() else 'cpu')
+        self.device = device
         self.half = half
         
         # Load model
@@ -99,8 +100,10 @@ class YOLOV6:
         self.hide_labels = hide_labels
         self.hide_conf = hide_conf
         self.view_img = view_img
-        self.font_path = font
-        
+        if hf_model:
+            self.weights = attempt_download_from_hub(weights, hf_token=None)
+        else:
+            self.weights = weights
 
     
     def load_model(self):
@@ -158,9 +161,8 @@ class YOLOV6:
             img_ori = img_src.copy()
 
             # check image and font
-            Inferer.font_check(self.font_path)
             assert img_ori.data.contiguous, 'Image needs to be contiguous. Please apply to input images with np.ascontiguousarray(im).'
-            
+            Inferer.font_check()
 
             det[:, :4] = Inferer.rescale(img.shape[2:], det[:, :4], img_src.shape).round()
             for *xyxy, conf, cls in reversed(det):
@@ -220,9 +222,6 @@ class YOLOV6:
                         save_path = str(Path(save_path).with_suffix('.mp4'))  # force *.mp4 suffix on results videos
                         vid_writer = cv2.VideoWriter(save_path, cv2.VideoWriter_fourcc(*'mp4v'), fps, (w, h))
                     vid_writer.write(img_src)
-                
-                return save_path
-                
 
     
 if __name__ == '__main__':
